# Advanced Number Game 
This package is an alternative to other non-advanced number game packages, within containing functions to continue play and select difficulty
# Installation
This package can be installed from PyPI
```
pip install advanced_number_game
```
# How to use
To play this number game, call the program
```
number_game
```
